@@ -1,7 +1,7 @@
 package ci
 
 import (
-	"github.com/MakeNowJust/heredoc"
+	"github.com/MakeNowJust/heredoc/v2"
 	"github.com/spf13/cobra"
 	"gitlab.com/gitlab-org/cli/commands/cmdutils"
 	jobArtifact "gitlab.com/gitlab-org/cli/commands/job/artifact"
