@@ -11,7 +11,7 @@ import (
 
 	"gitlab.com/gitlab-org/cli/commands/cmdtest"
 
-	"github.com/MakeNowJust/heredoc"
+	"github.com/MakeNowJust/heredoc/v2"
 
 	"github.com/stretchr/testify/assert"
 	"github.com/xanzy/go-gitlab"
