@@ -202,3 +202,99 @@ func TestReleaseCreateWithFiles(t *testing.T) {
 		})
 	}
 }
+
+func TestReleaseCreate_WithAssetsLinksJSON(t *testing.T) {
+	tests := []struct {
+		name           string
+		cli            string
+		expectedOutput string
+	}{
+		{
+			name: "with direct_asset_path",
+			cli:  `0.0.1 --assets-links='[{"name": "any-name", "url": "https://example.com/any-asset-url", "direct_asset_path": "/any-path"}]'`,
+			expectedOutput: `• Validating tag 0.0.1
+
+• Creating or updating release repo=OWNER/REPO tag=0.0.1
+✓ Release created	url=https://gitlab.com/OWNER/REPO/-/releases/0.0.1
+• Uploading release assets repo=OWNER/REPO tag=0.0.1
+✓ Added release asset	name=any-name url=https://gitlab.example.com/OWNER/REPO/releases/0.0.1/downloads/any-path
+✓ Release succeeded after`,
+		},
+		{
+			name: "with filepath aliased to direct_asset_path",
+			cli:  `0.0.1 --assets-links='[{"name": "any-name", "url": "https://example.com/any-asset-url", "filepath": "/any-path"}]'`,
+			expectedOutput: `• Validating tag 0.0.1
+
+• Creating or updating release repo=OWNER/REPO tag=0.0.1
+✓ Release created	url=https://gitlab.com/OWNER/REPO/-/releases/0.0.1
+• Uploading release assets repo=OWNER/REPO tag=0.0.1
+✓ Added release asset	name=any-name url=https://gitlab.example.com/OWNER/REPO/releases/0.0.1/downloads/any-path
+	! Aliased deprecated ` + "`filepath`" + ` field to ` + "`direct_asset_path`" + `. Replace ` + "`filepath`" + ` with ` + "`direct_asset_path`" + `	name=any-name
+✓ Release succeeded after`,
+		},
+	}
+
+	for _, tt := range tests {
+		t.Run(tt.name, func(t *testing.T) {
+			fakeHTTP := &httpmock.Mocker{
+				MatchURL: httpmock.PathAndQuerystring,
+			}
+			defer fakeHTTP.Verify(t)
+
+			fakeHTTP.RegisterResponder(http.MethodGet, "/api/v4/projects/OWNER/REPO/releases/0%2E0%2E1",
+				httpmock.NewStringResponse(http.StatusNotFound, `{"message":"404 Not Found"}`))
+
+			fakeHTTP.RegisterResponder(http.MethodPost, "/api/v4/projects/OWNER/REPO/releases",
+				func(req *http.Request) (*http.Response, error) {
+					rb, _ := io.ReadAll(req.Body)
+
+					assert.NotContains(t, string(rb), `"direct_asset_path":`)
+					assert.NotContains(t, string(rb), `"filepath":`)
+
+					resp, _ := httpmock.NewStringResponse(http.StatusCreated, `
+						{
+							"name": "test_release",
+							"tag_name": "0.0.1",
+							"description": null,
+							"created_at": "2023-01-19T02:58:32.622Z",
+							"released_at": "2023-01-19T02:58:32.622Z",
+							"upcoming_release": false,
+							"tag_path": "/OWNER/REPO/-/tags/0.0.1",
+							"_links": {
+								"self": "https://gitlab.com/OWNER/REPO/-/releases/0.0.1"
+							}
+						}
+					`)(req)
+					return resp, nil
+				},
+			)
+
+			fakeHTTP.RegisterResponder(http.MethodPost, "/api/v4/projects/OWNER/REPO/releases/0%2E0%2E1/assets/links",
+				func(req *http.Request) (*http.Response, error) {
+					rb, _ := io.ReadAll(req.Body)
+
+					assert.Contains(t, string(rb), `"direct_asset_path":"/any-path"`)
+					assert.NotContains(t, string(rb), `"filepath":`)
+
+					resp, _ := httpmock.NewStringResponse(http.StatusCreated, `
+						{
+							"id":1,
+							"name":"any-name",
+							"url":"https://example.com/any-asset-url",
+							"direct_asset_url":"https://gitlab.example.com/OWNER/REPO/releases/0.0.1/downloads/any-path",
+							"link_type":"other"
+						}
+					`)(req)
+					return resp, nil
+				},
+			)
+
+			output, err := runCommand(fakeHTTP, false, tt.cli)
+
+			if assert.NoErrorf(t, err, "error running command `create %s`: %v", tt.cli, err) {
+				assert.Contains(t, output.Stderr(), tt.expectedOutput)
+				assert.Empty(t, output.String())
+			}
+		})
+	}
+}
